import LayoutType from '../Models/layoutType';
/**
 * Root class for drivers
 */
export default class Driver {
    /**
     * Default constructor
     */
    constructor();
    /**
     * Name of the device
     */
    DeviceName: string;
    /**
     * Midi In port name
     */
    MidiIn: string;
    /**
     * Midi Out port name
     */
    MidiOut: string;
    /**
     * Dictionary between Node usable commands and Device features
     */
    Dictionary: {
        command: {
            /**
             * SysEx Header
             */
            sysexHeader: Array<number>;
            /**
             * SysEx Footer
             */
            sysexFooter: number;
            /**
             * Select layout command
             */
            selectLayout: number;
            /**
             * Led SysEx command
             */
            ledLightning: number;
            /**
             * Text scolling command
             */
            textScrolling: number;
            /**
             * Brightness level command
             */
            ledBrightness: number;
            /**
             * Programmer or Live mode command
             */
            programmer: number;
            /**
             * Channels for LightningCustomMode
             */
            LightningCustomMode: {
                static: number;
                flashing: number;
                pulsing: number;
            };
            /**
             * DAW Mode
             */
            daw: number;
            /**
             * Clear DAW
             */
            dawClear: number;
            /**
             * Session button color
             */
            sessionColor: number;
            /**
             * LED Sleep
             */
            ledSleep: number;
        };
        input: {
            onNote: number;
        };
    };
    private queryBuilder;
    private featureCheck;
    /**
     * DriverQuery: feat: setLayout
     * @param {number} layout Layout number
     * @returns {Array<number>}
     */
    setLayout(layout: LayoutType): number[];
    /**
     * DriverQuery: feat: textScrolling
     * @param {number} color Index color
     * @param {string} text Text to display
     * @param {boolean} [shouldLoop=false] Show loop the message
     * @param {number} [speed=7] Speed
     * @returns {Array<number>}
     */
    textScrolling(color: number, text: string, shouldLoop?: boolean, speed?: number): number[];
    /**
     * DriverQuery: feat: programmerToogle
     * @param {boolean} bool Enable or disable programmer mode (switch from Live)
     * @returns {Array<number>}
     */
    programmerToggle(bool: boolean): number[];
    /**
     * DriverQuery: feat: dawToogle
     * @param {boolean} bool Enable or disable DAW mode (switch from Live)
     * @returns {Array<number>}
     */
    dawToogle(bool: boolean): number[];
    /**
     * DriverQuery: feat: dawClear
     * @param {boolean} session Clear session layout (true by default)
     * @param {boolean} drumrack Clear drumrack layout (true by default)
     * @param {boolean} controlchange Clear controlchange layout (true by default)
     * @returns {Array<number>}
     */
    dawClear(session?: boolean, drumrack?: boolean, controlchange?: boolean): number[];
    /**
     * DriverQuery: feat: ledLightning
     * @param {Array<number>} colors Array with colors to change (refer to Programmer Manual of your Launchpad)
     * @returns {Array<number>}
     */
    ledLightning(colors: Array<number>): number[];
    /**
     * DriverQuery: feat: ledBrightness
     * @param {number} brightness Brightness for the Launchpad (between 0 and 127)
     * @returns {Array<number>}
     */
    ledBrightness(brightness: number): number[];
    /**
     * DriverQuery: feat: ledBrightness
     * @param {boolean} sleep Disable light of all pads (true by default)
     * @returns {Array<number>}
     */
    ledSleep(sleep?: boolean): number[];
}
