"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("util");
/**
 * Root class for drivers
 */
class Driver {
    /**
     * Default constructor
     */
    constructor() {
        this.DeviceName = 'default';
        this.MidiIn = '';
        this.MidiOut = '';
        this.Dictionary = {
            command: {
                sysexHeader: [-1],
                sysexFooter: -1,
                selectLayout: -1,
                ledLightning: -1,
                textScrolling: -1,
                ledBrightness: -1,
                programmer: -1,
                LightningCustomMode: {
                    static: -1,
                    flashing: -1,
                    pulsing: -1,
                },
                daw: -1,
                dawClear: -1,
                sessionColor: -1,
                ledSleep: -1
            },
            input: {
                onNote: 144,
            }
        };
    }
    queryBuilder(data) {
        return Array().concat(this.Dictionary.command.sysexHeader, data, [this.Dictionary.command.sysexFooter]);
    }
    featureCheck(feat) {
        return feat in this.Dictionary.command;
    }
    /*
     * Public methods
     */
    /**
     * DriverQuery: feat: setLayout
     * @param {number} layout Layout number
     * @returns {Array<number>}
     */
    setLayout(layout) {
        return this.queryBuilder([this.Dictionary.command.selectLayout, layout]);
    }
    /**
     * DriverQuery: feat: textScrolling
     * @param {number} color Index color
     * @param {string} text Text to display
     * @param {boolean} [shouldLoop=false] Show loop the message
     * @param {number} [speed=7] Speed
     * @returns {Array<number>}
     */
    textScrolling(color, text, shouldLoop = false, speed = 7) {
        return this.queryBuilder([this.Dictionary.command.textScrolling, +shouldLoop, speed, 0, color].concat(Array.from(new util_1.TextEncoder().encode(text))));
    }
    /**
     * DriverQuery: feat: programmerToogle
     * @param {boolean} bool Enable or disable programmer mode (switch from Live)
     * @returns {Array<number>}
     */
    programmerToggle(bool) {
        return this.queryBuilder([this.Dictionary.command.programmer, +bool]);
    }
    /**
     * DriverQuery: feat: dawToogle
     * @param {boolean} bool Enable or disable DAW mode (switch from Live)
     * @returns {Array<number>}
     */
    dawToogle(bool) {
        return this.queryBuilder([this.Dictionary.command.daw, +bool]);
    }
    /**
     * DriverQuery: feat: dawClear
     * @param {boolean} session Clear session layout (true by default)
     * @param {boolean} drumrack Clear drumrack layout (true by default)
     * @param {boolean} controlchange Clear controlchange layout (true by default)
     * @returns {Array<number>}
     */
    dawClear(session = true, drumrack = true, controlchange = true) {
        return this.queryBuilder([this.Dictionary.command.dawClear, +session, +drumrack, +controlchange]);
    }
    /**
     * DriverQuery: feat: ledLightning
     * @param {Array<number>} colors Array with colors to change (refer to Programmer Manual of your Launchpad)
     * @returns {Array<number>}
     */
    ledLightning(colors) {
        return this.queryBuilder(Array().concat([this.Dictionary.command.ledLightning], colors));
    }
    /**
     * DriverQuery: feat: ledBrightness
     * @param {number} brightness Brightness for the Launchpad (between 0 and 127)
     * @returns {Array<number>}
     */
    ledBrightness(brightness) {
        return this.queryBuilder([this.Dictionary.command.ledBrightness, brightness]);
    }
    /**
     * DriverQuery: feat: ledBrightness
     * @param {boolean} sleep Disable light of all pads (true by default)
     * @returns {Array<number>}
     */
    ledSleep(sleep = false) {
        return this.queryBuilder([this.Dictionary.command.ledSleep, +!sleep]);
    }
}
exports.default = Driver;
